@@ -1123,6 +1123,10 @@ class SystemTrayIcon(KSystemTrayIcon):
             self.toolTip.show()
             x = self.geometry().x() - self.toolTip.width()
             y = self.geometry().y() - self.toolTip.height()
+            if x < 0:
+                x += self.geometry().width() + self.toolTip.width()
+            if y < 0:
+                y += self.geometry().height() + self.toolTip.height()
             self.toolTip.move(x, y)
             QTimer.singleShot(3000, self.hideToolTip)
             return True
